@@ -3,7 +3,7 @@ package Complete::Getopt::Long;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-04-10'; # DATE
 our $DIST = 'Complete-Getopt-Long'; # DIST
-our $VERSION = '0.476'; # VERSION
+our $VERSION = '0.477'; # VERSION
 
 use 5.010001;
 use strict;
@@ -319,6 +319,9 @@ sub complete_cli_arg {
     log_trace('[comp][compgl] entering %s(), words=%s, cword=%d, word=<%s>',
               $fname, \@words, $cword, $words[$cword]) if $COMPLETE_GETOPT_LONG_TRACE;
 
+    # strip hash storage from getopt_spec
+    shift @$gospec if ref $gospec->[0] eq 'HASH';
+
     # parse all options first & supply default completion routine
     my %opts;
     my $i = -1;
@@ -767,7 +770,7 @@ Complete::Getopt::Long - Complete command-line argument using Getopt::Long speci
 
 =head1 VERSION
 
-This document describes version 0.476 of Complete::Getopt::Long (from Perl distribution Complete-Getopt-Long), released on 2020-04-10.
+This document describes version 0.477 of Complete::Getopt::Long (from Perl distribution Complete-Getopt-Long), released on 2020-04-10.
 
 =head1 SYNOPSIS
 
